@@ -40,8 +40,8 @@ from phonopy import Phonopy, PhonopyGruneisen, PhonopyQHA, __version__
 import phonopy.file_IO as file_IO
 from phonopy.cui.settings import PhonopyConfParser
 from phonopy.cui.show_symmetry import check_symmetry
-from phonopy.cui.phonopy_argparse import get_parser
-from phonopy.cui.phonopy_argparse import get_parser
+from phonopy.cui.phonopy_argparse import (get_parser,
+                                          show_deprecated_option_warnings)
 from phonopy.structure.cells import print_cell, determinant
 from phonopy.structure.atoms import atom_data, symbol_map
 from phonopy.interface import (create_FORCE_SETS, read_crystal_structure,
@@ -218,60 +218,21 @@ def print_settings(settings):
         for v in settings.get_primitive_matrix():
             print("    %s" % v)
 
-###########################
-# Primitive option parser #
-###########################
+#################
+# Option parser #
+#################
 
-parser = get_parser()
-(options, args) = parser.parse_args()
-option_list = parser.option_list
+parser, deprecated = get_parser()
+args = parser.parse_args()
 
 # Set log level
 log_level = 1
-if options.verbose:
+if args.verbose:
     log_level = 2
-if options.quiet or options.is_check_symmetry:
+if args.quiet or args.is_check_symmetry:
     log_level = 0
-if options.loglevel is not None:
-    log_level = options.loglevel
-
-#
-# Phonopy interface mode
-#
-if options.wien2k_mode:
-    interface_mode = 'wien2k'
-    from phonopy.interface.wien2k import write_supercells_with_displacements
-elif options.abinit_mode:
-    interface_mode = 'abinit'
-    from phonopy.interface.abinit import write_supercells_with_displacements
-elif options.pwscf_mode:
-    interface_mode = 'pwscf'
-    from phonopy.interface.pwscf import write_supercells_with_displacements
-elif options.elk_mode:
-    interface_mode = 'elk'
-    from phonopy.interface.elk import write_supercells_with_displacements
-elif options.siesta_mode:
-    interface_mode = 'siesta'
-    from phonopy.interface.siesta import write_supercells_with_displacements
-elif options.cp2k_mode:
-    interface_mode = 'cp2k'
-    from phonopy.interface.cp2k import write_supercells_with_displacements
-elif options.crystal_mode:
-    interface_mode = 'crystal'
-    from phonopy.interface.crystal import write_supercells_with_displacements
-else:
-    if options.vasp_mode:
-        interface_mode = 'vasp'
-    else:
-        interface_mode = None
-    from phonopy.interface.vasp import write_supercells_with_displacements
-    from phonopy.interface.vasp import create_FORCE_CONSTANTS
-
-physical_units = get_default_physical_units(interface_mode)
-
-if options.is_graph_save:
-    import matplotlib
-    matplotlib.use('Agg')
+if args.loglevel is not None:
+    log_level = args.loglevel
 
 ################
 # Phonopy logo #
@@ -281,37 +242,90 @@ if log_level > 0:
     print_phononpy()
     print_version(phonopy_version)
 
+    if deprecated:
+        show_deprecated_option_warnings(deprecated)
+
+##########################
+# Phonopy interface mode #
+##########################
+if args.wien2k_mode:
+    interface_mode = 'wien2k'
+    from phonopy.interface.wien2k import write_supercells_with_displacements
+elif args.abinit_mode:
+    interface_mode = 'abinit'
+    from phonopy.interface.abinit import write_supercells_with_displacements
+elif args.pwscf_mode:
+    interface_mode = 'pwscf'
+    from phonopy.interface.pwscf import write_supercells_with_displacements
+elif args.elk_mode:
+    interface_mode = 'elk'
+    from phonopy.interface.elk import write_supercells_with_displacements
+elif args.siesta_mode:
+    interface_mode = 'siesta'
+    from phonopy.interface.siesta import write_supercells_with_displacements
+elif args.cp2k_mode:
+    interface_mode = 'cp2k'
+    from phonopy.interface.cp2k import write_supercells_with_displacements
+elif args.crystal_mode:
+    interface_mode = 'crystal'
+    from phonopy.interface.crystal import write_supercells_with_displacements
+else:
+    if args.vasp_mode:
+        interface_mode = 'vasp'
+    else:
+        interface_mode = None
+    from phonopy.interface.vasp import write_supercells_with_displacements
+    from phonopy.interface.vasp import create_FORCE_CONSTANTS
+
+physical_units = get_default_physical_units(interface_mode)
+
+if args.is_graph_save:
+    import matplotlib
+    matplotlib.use('Agg')
+
 ###########################
 # Integrated helper tools #
 ###########################
 
 # Create FORCE_SETS (-f or --force_sets)
-if options.force_sets_mode or options.force_sets_zero_mode:
+if args.force_sets or args.force_sets_zero:
+    if args.force_sets:
+        filenames = args.force_sets
+        force_sets_zero_mode = False
+    elif args.force_sets_zero:
+        filenames = args.force_sets_zero
+        force_sets_zero_mode = True
+    else:
+        print_error_message("Something wrong for parsing arguments.")
+        sys.exit(0)
+
     file_exists('disp.yaml', log_level)
-    for filename in args:
+    for filename in filenames:
         file_exists(filename, log_level)
+
+    if force_sets_zero_mode:
+        print("Forces in %s are subtracted from forces in all other files." %
+              filenames[0])
+
     error_num = create_FORCE_SETS(
         interface_mode,
-        args,
-        options.symprec,
-        is_wien2k_p1=options.is_wien2k_p1,
-        force_sets_zero_mode=options.force_sets_zero_mode,
+        filenames,
+        args.symprec,
+        is_wien2k_p1=args.is_wien2k_p1,
+        force_sets_zero_mode=force_sets_zero_mode,
         log_level=log_level)
     if log_level > 0:
         print_end()
     sys.exit(error_num)
 
 # Create FORCE_CONSTANTS (--fc or --force_constants)
-if options.force_constants_mode:
-    if len(args) > 0:
-        file_exists(args[0], log_level)
-        error_num = create_FORCE_CONSTANTS(args[0],
-                                           options.is_hdf5,
-                                           log_level)
-    else:
-        print_error_message("Please specify vasprun.xml.")
-        error_num = 1
-
+if args.force_constants:
+    filename = args.force_constants[0]
+    file_exists(filename, log_level)
+    write_hdf5 = (args.is_hdf5 or
+                  args.fc_format == 'hdf5' or
+                  args.writefc_format == 'hdf5')
+    error_num = create_FORCE_CONSTANTS(filename, write_hdf5, log_level)
     if log_level > 0:
         print_end()
     sys.exit(error_num)
@@ -319,15 +333,12 @@ if options.force_constants_mode:
 #########################
 # Read phonopy settings #
 #########################
-if len(args) > 0:
-    if file_exists(args[0], log_level):
-        phonopy_conf = PhonopyConfParser(filename=args[0],
-                                         options=options,
-                                         option_list=option_list)
+if len(args.conf_file) > 0:
+    if file_exists(args.conf_file[0], log_level):
+        phonopy_conf = PhonopyConfParser(filename=args.conf_file[0], args=args)
         settings = phonopy_conf.get_settings()
 else:
-    phonopy_conf = PhonopyConfParser(options=options,
-                                     option_list=option_list)
+    phonopy_conf = PhonopyConfParser(args=args)
     settings = phonopy_conf.get_settings()
 
 ##################
@@ -369,10 +380,10 @@ if magmoms is not None:
 ################################################
 # Check crystal symmetry and exit (--symmetry) #
 ################################################
-if options.is_check_symmetry:
+if args.is_check_symmetry:
     check_symmetry(unitcell,
                    primitive_axis=settings.get_primitive_matrix(),
-                   symprec=options.symprec,
+                   symprec=args.symprec,
                    distance_to_A=physical_units['distance_to_A'],
                    phonopy_version=phonopy_version)
     if log_level > 0:
@@ -394,14 +405,14 @@ if settings.get_supercell_matrix() is None:
 if run_mode == 'displacements':
     phonon = Phonopy(unitcell,
                      settings.get_supercell_matrix(),
-                     symprec=options.symprec,
+                     symprec=args.symprec,
                      is_symmetry=settings.get_is_symmetry(),
                      log_level=log_level)
 else: # Read FORCE_SETS, FORCE_CONSTANTS, or force_constants.hdf5
     num_atom = unitcell.get_number_of_atoms()
     num_satom = determinant(settings.get_supercell_matrix()) * num_atom
-    if settings.get_is_force_constants() == 'read':
-        if settings.get_is_hdf5():
+    if settings.get_read_force_constants():
+        if settings.get_is_hdf5() or settings.get_readfc_format() == 'hdf5':
             try:
                 import h5py
             except ImportError:
@@ -424,7 +435,7 @@ else: # Read FORCE_SETS, FORCE_CONSTANTS, or force_constants.hdf5
         if fc.shape[0] != num_satom:
             error_text = ("Number of atoms in supercell is not consistent with "
                           "the matrix shape of\nforce constants read from ")
-            if settings.get_is_hdf5():
+            if settings.get_is_hdf5() or settings.get_readfc_format() == 'hdf5':
                 error_text += "force_constants.hdf5.\n"
             else:
                 error_text += "FORCE_CONSTANTS.\n"
@@ -457,7 +468,7 @@ else: # Read FORCE_SETS, FORCE_CONSTANTS, or force_constants.hdf5
                      factor=physical_units['factor'],
                      dynamical_matrix_decimals=settings.get_dm_decimals(),
                      force_constants_decimals=settings.get_fc_decimals(),
-                     symprec=options.symprec,
+                     symprec=args.symprec,
                      is_symmetry=settings.get_is_symmetry(),
                      use_lapack_solver=settings.get_lapack_solver(),
                      log_level=log_level)
@@ -560,14 +571,14 @@ if run_mode == 'displacements':
 ########################################
 # Preparations for phonon calculations #
 ########################################
-if settings.get_is_force_constants() == 'read':
+if settings.get_read_force_constants():
     phonon.set_force_constants(fc)
 elif os.path.exists("FORCE_SETS"):
     phonon.set_displacement_dataset(force_sets)
     if log_level > 0:
         print("Computing force constants...")
 
-    if (settings.get_is_force_constants() == "write" or
+    if (settings.get_write_force_constants() or
         settings.get_fc_symmetry_iteration() > 0 or
         settings.get_fc_spg_symmetry()):
         # Need to calculate full force constant tensors
@@ -634,8 +645,8 @@ if settings.get_fc_symmetry_iteration() > 0:
     phonon.symmetrize_force_constants(settings.get_fc_symmetry_iteration())
 
 # Write FORCE_CONSTANTS
-if settings.get_is_force_constants() == "write":
-    if settings.get_is_hdf5():
+if settings.get_write_force_constants():
+    if settings.get_is_hdf5() or settings.get_writefc_format() == 'hdf5':
         file_IO.write_force_constants_to_hdf5(phonon.get_force_constants())
         if log_level > 0:
             print("Force constants are written into force_constants.hdf5.")
@@ -674,23 +685,28 @@ if settings.get_is_group_velocity():
 
 # QPOINTS mode
 if run_mode == 'qpoints':
-    if settings.get_qpoints():
+    if settings.get_read_qpoints():
+        q_points = file_IO.parse_QPOINTS()
+        if log_level > 0:
+            print("Frequencies at q-points given by QPOINTS:")
+    elif settings.get_qpoints():
         q_points = settings.get_qpoints()
         if log_level > 0:
             print("Q-points that will be calculated at:")
             for q in q_points:
                 print("    %s" % q)
     else:
-        q_points = file_IO.parse_QPOINTS()
         if log_level > 0:
-            print("Frequencies at q-points given by QPOINTS:")
+            print_error_message("Q-points are not properly specified.")
+            print_end()
+        sys.exit(1)
     phonon.set_qpoints_phonon(
         q_points,
         nac_q_direction=settings.get_nac_q_direction(),
         is_eigenvectors=settings.get_is_eigenvectors(),
         write_dynamical_matrices=settings.get_write_dynamical_matrices())
 
-    if settings.get_is_hdf5():
+    if settings.get_is_hdf5() or settings.get_qpoints_format() == "hdf5":
         phonon.write_hdf5_qpoints_phonon()
     else:
         phonon.write_yaml_qpoints_phonon()
@@ -698,7 +714,15 @@ if run_mode == 'qpoints':
 # Band structure and mesh sampling
 elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
     if run_mode == 'band' or run_mode == 'band_mesh':
-        bands = settings.get_bands()
+        from phonopy.phonon.band_structure import get_band_qpoints
+
+        band_paths = settings.get_band_paths()
+        if settings.get_band_points() is None:
+            npoints = 51
+        else:
+            npoints = settings.get_band_points()
+        bands = get_band_qpoints(band_paths, npoints)
+
         if log_level > 0:
             print("Reciprocal space paths in reduced coordinates:")
             for band in bands:
@@ -714,16 +738,16 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
         else:
             comment = {'calculator': interface_mode}
 
-        if settings.get_is_hdf5():
+        if settings.get_is_hdf5() or settings.get_band_format() == 'hdf5':
             phonon.write_hdf5_band_structure(labels=settings.get_band_labels(),
                                              comment=comment)
         else:
             phonon.write_yaml_band_structure(labels=settings.get_band_labels(),
                                              comment=comment)
 
-        if options.is_graph_plot and run_mode != 'band_mesh':
+        if args.is_graph_plot and run_mode != 'band_mesh':
             plot = phonon.plot_band_structure(labels=settings.get_band_labels())
-            if options.is_graph_save:
+            if args.is_graph_save:
                 plot.savefig('band.pdf')
             else:
                 plot.show()
@@ -760,11 +784,12 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                     print("Number of q-points on sampling mesh: %d" %
                           weights.shape[0])
                 print("Calculating phonons on sampling mesh...")
-    
+
             phonon.run_mesh()
 
             if settings.get_write_mesh():
-                if settings.get_is_hdf5():
+                if (settings.get_is_hdf5() or
+                    settings.get_mesh_format() == 'hdf5'):
                     phonon.write_hdf5_mesh()
                 else:
                     phonon.write_yaml_mesh()
@@ -805,9 +830,9 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                     print(("%12.3f " + "%15.7f" * 4) %
                           (T, F, S, CV, F + T * S / 1000))
 
-            if options.is_graph_plot:
+            if args.is_graph_plot:
                 plot = phonon.plot_thermal_properties()
-                if options.is_graph_save:
+                if args.is_graph_save:
                     plot.savefig('thermal_properties.pdf')
                 else:
                     plot.show()
@@ -836,9 +861,9 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                 cutoff_frequency=settings.get_cutoff_frequency())
             phonon.write_yaml_thermal_displacements()
 
-            if options.is_graph_plot:
-                plot = phonon.plot_thermal_displacements(options.is_legend)
-                if options.is_graph_save:
+            if args.is_graph_plot:
+                plot = phonon.plot_thermal_displacements(args.is_legend)
+                if args.is_graph_save:
                     plot.savefig('thermal_displacement.pdf')
                 else:
                     plot.show()
@@ -903,24 +928,24 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                 xyz_projection=settings.get_xyz_projection())
             phonon.write_partial_DOS()
 
-            if options.is_graph_plot:
+            if args.is_graph_plot:
                 pdos_indices = settings.get_pdos_indices()
                 if not pdos_indices:
                     num_atom = primitive.get_number_of_atoms()
                     pdos_indices = [np.arange(num_atom) * 3 + i
                                     for i in range(3)]
 
-            if options.is_graph_plot and run_mode != 'band_mesh':
+            if args.is_graph_plot and run_mode != 'band_mesh':
                 plot = phonon.plot_partial_DOS(
                     pdos_indices=pdos_indices,
                     legend=([np.array(x) + 1 for x in pdos_indices]))
-                if options.is_graph_save:
+                if args.is_graph_save:
                     plot.savefig('partial_dos.pdf')
                 else:
                     plot.show()
 
         # Total DOS
-        elif (options.is_graph_plot or settings.get_is_dos_mode()):
+        elif (args.is_graph_plot or settings.get_is_dos_mode()):
             dos_range = settings.get_dos_range()
 
             phonon.set_total_DOS(
@@ -940,9 +965,9 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                     print("Debye frequency: %10.5f" % debye_freq)
             phonon.write_total_DOS()
 
-            if options.is_graph_plot and run_mode != 'band_mesh':
+            if args.is_graph_plot and run_mode != 'band_mesh':
                 plot = phonon.plot_total_DOS()
-                if options.is_graph_save:
+                if args.is_graph_save:
                     plot.savefig('total_dos.pdf')
                 else:
                     plot.show()
@@ -997,7 +1022,7 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                     print(text)
 
     if (run_mode == 'band_mesh' and
-        options.is_graph_plot and
+        args.is_graph_plot and
         not settings.get_is_thermal_properties() and
         not settings.get_is_thermal_displacements() and
         not settings.get_is_thermal_displacement_matrices() and
@@ -1009,7 +1034,7 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
         else:
             plot = phonon.plot_band_structure_and_dos(
                 labels=settings.get_band_labels())
-        if options.is_graph_save:
+        if args.is_graph_save:
             plot.savefig('band_dos.pdf')
         else:
             plot.show()
